@@ -30,7 +30,7 @@ struct KisComboBasedPaintOpProperty::Private
 
 KisComboBasedPaintOpProperty::KisComboBasedPaintOpProperty(const QString &id,
                                                            const QString &name,
-                                                           KisPaintOpSettingsSP settings,
+                                                           KisPaintOpSettingsRestrictedSP settings,
                                                            QObject *parent)
     : KisUniformPaintOpProperty(Combo, id, name, settings, parent),
       m_d(new Private)
@@ -40,7 +40,7 @@ KisComboBasedPaintOpProperty::KisComboBasedPaintOpProperty(const QString &id,
 KisComboBasedPaintOpProperty::KisComboBasedPaintOpProperty(Type type,
                                                            const QString &id,
                                                            const QString &name,
-                                                           KisPaintOpSettingsSP settings,
+                                                           KisPaintOpSettingsRestrictedSP settings,
                                                            QObject *parent)
     : KisUniformPaintOpProperty(Combo, id, name, settings, parent),
       m_d(new Private)
