@@ -64,19 +64,12 @@ public:
     void toggleProperty(KisBaseNode::PropertyList &props, OptionalProperty prop, bool controlPressed, const QModelIndex &index);
 };
 
-void KisNodeDelegate::slotOnCloseEditor()
-{
-    KisPart::currentInputManager()->slotFocusOnEnter(true);
-}
-
 KisNodeDelegate::KisNodeDelegate(KisNodeView *view, QObject *parent)
     : QAbstractItemDelegate(parent)
     , d(new Private)
 {
     d->view = view;
     QApplication::instance()->installEventFilter(this);
-
-    connect(this, SIGNAL(closeEditor(QWidget*)), this, SLOT(slotOnCloseEditor()));
 }
 
 KisNodeDelegate::~KisNodeDelegate()
@@ -96,7 +89,7 @@ void KisNodeDelegate::paint(QPainter *p, const QStyleOptionViewItem &o, const QM
     p->save();
 
     {
-	QStyleOptionViewItemV4 option = getOptions(o, index);
+        QStyleOptionViewItem option = getOptions(o, index);
         QStyle *style = option.widget ? option.widget->style() : QApplication::style();
         style->drawPrimitive(QStyle::PE_PanelItemViewItem, &option, p, option.widget);
 
@@ -475,7 +468,7 @@ void KisNodeDelegate::drawIcons(QPainter *p, const QStyleOptionViewItem &option,
             const qreal oldOpacity = p->opacity(); // remember previous opacity
 
 
-            if (fullColor) {              
+            if (fullColor) {
                  p->setOpacity(1.0);
             }
             else {
@@ -733,7 +726,6 @@ bool KisNodeDelegate::editorEvent(QEvent *event, QAbstractItemModel *model, cons
 
 QWidget *KisNodeDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem&, const QModelIndex&) const
 {
-    KisPart::currentInputManager()->slotFocusOnEnter(false);
     d->edit = new QLineEdit(parent);
     d->edit->installEventFilter(const_cast<KisNodeDelegate*>(this)); //hack?
     return d->edit;
@@ -819,9 +811,9 @@ bool KisNodeDelegate::eventFilter(QObject *object, QEvent *event)
 // PRIVATE
 
 
-QStyleOptionViewItemV4 KisNodeDelegate::getOptions(const QStyleOptionViewItem &o, const QModelIndex &index)
+QStyleOptionViewItem KisNodeDelegate::getOptions(const QStyleOptionViewItem &o, const QModelIndex &index)
 {
-    QStyleOptionViewItemV4 option = o;
+    QStyleOptionViewItem option = o;
     QVariant v = index.data(Qt::FontRole);
     if (v.isValid()) {
         option.font = v.value<QFont>();
@@ -854,7 +846,7 @@ void KisNodeDelegate::drawProgressBar(QPainter *p, const QStyleOptionViewItem &o
         {
             p->setClipRect(r);
             QStyle* style = QApplication::style();
-            QStyleOptionProgressBarV2 opt;
+            QStyleOptionProgressBar opt;
 
             opt.minimum = 0;
             opt.maximum = 100;
