@@ -104,11 +104,9 @@ void KisToolProxy::forwardHoverEvent(QEvent *event)
 
 bool KisToolProxy::forwardEvent(ActionState state, KisTool::ToolAction action, QEvent *event, QEvent *originalEvent)
 {
-    qDebug() << state << action << event << originalEvent;
     bool retval = true;
 
     QTabletEvent *tabletEvent = dynamic_cast<QTabletEvent*>(event);
-    QTouchEvent *touchEvent = dynamic_cast<QTouchEvent*>(event);
     QMouseEvent *mouseEvent = dynamic_cast<QMouseEvent*>(event);
 
     if (tabletEvent) {
@@ -118,17 +116,6 @@ bool KisToolProxy::forwardEvent(ActionState state, KisTool::ToolAction action, Q
         forwardToTool(state, action, tabletEvent, docPoint);
         retval = tabletEvent->isAccepted();
     }
-    else if (touchEvent) {
-        if (state == END && touchEvent->type() != QEvent::TouchEnd) {
-            //Fake a touch end if we are "upgrading" a single-touch gesture to a multi-touch gesture.
-            QTouchEvent fakeEvent(QEvent::TouchEnd, touchEvent->device(),
-                                  touchEvent->modifiers(), touchEvent->touchPointStates(),
-                                  touchEvent->touchPoints());
-            this->touchEvent(&fakeEvent);
-        } else {
-            this->touchEvent(touchEvent);
-        }
-    }
     else if (mouseEvent) {
         QPointF docPoint = widgetToDocument(mouseEvent->posF());
         mouseEvent->accept();
