@@ -45,7 +45,7 @@ class KisLayerManager : public QObject
 public:
 
     KisLayerManager(KisViewManager * view);
-    ~KisLayerManager();
+    ~KisLayerManager() override;
     void setView(QPointer<KisView>view);
 
 Q_SIGNALS:
@@ -102,7 +102,7 @@ private Q_SLOTS:
     void addShapeLayer(KisNodeSP activeNode);
 
     void addAdjustmentLayer(KisNodeSP activeNode);
-    KisAdjustmentLayerSP addAdjustmentLayer(KisNodeSP activeNode, const QString & name, KisFilterConfiguration * filter, KisSelectionSP selection);
+    KisAdjustmentLayerSP addAdjustmentLayer(KisNodeSP activeNode, const QString & name, KisFilterConfigurationSP  filter, KisSelectionSP selection);
 
     void addGeneratorLayer(KisNodeSP activeNode);
 
