@@ -29,9 +29,9 @@ class KisTGAImport : public KisImportExportFilter
     Q_OBJECT
 public:
     KisTGAImport(QObject *parent, const QVariantList &);
-    virtual ~KisTGAImport();
+    ~KisTGAImport() override;
 public:
-    virtual KisImportExportFilter::ConversionStatus convert(const QByteArray& from, const QByteArray& to, KisPropertiesConfigurationSP configuration = 0);
+    KisImportExportFilter::ConversionStatus convert(const QByteArray& from, const QByteArray& to, KisPropertiesConfigurationSP configuration = 0) override;
 };
 
 #endif
